@@ -6,9 +6,7 @@ from datetime import datetime
 from pytz import timezone, UTC
 from bs4.element import ResultSet  # type: ignore
 
-from circuit_maintenance_parser.errors import ParsingError
 from circuit_maintenance_parser.parser import Html, Impact, CircuitImpact, Status
-from circuit_maintenance_parser.utils import city_timezone
 
 logger = logging.getLogger(__name__)
 
@@ -18,16 +16,12 @@ logger = logging.getLogger(__name__)
 class HtmlParserCogent1(Html):
     """Notifications Parser for Cogent notifications."""
 
-    def parse_html(self, soup, data_base):
+    def parse_html(self, soup):
         """Execute parsing."""
-        data = data_base.copy()
-        try:
-            self.parse_div(soup.find_all("div", class_="a3s aiL"), data)
-            self.parse_title(soup.find_all("title"), data)
-            return [data]
-
-        except Exception as exc:
-            raise ParsingError from exc
+        data = {}
+        self.parse_div(soup.find_all("div", class_="a3s aiL"), data)
+        self.parse_title(soup.find_all("title"), data)
+        return [data]
 
     def parse_div(self, divs: ResultSet, data: Dict):  # pylint: disable=too-many-locals
         """Parse <div> tag."""
@@ -53,7 +47,7 @@ class HtmlParserCogent1(Html):
                 elif line.startswith("Cogent customers receiving service"):
                     match = re.search(r"[^Cogent].*?((\b[A-Z][a-z\s-]+)+, ([A-Za-z-]+[\s-]))", line)
                     if match:
-                        parsed_timezone = city_timezone(match.group(1).strip())
+                        parsed_timezone = self._geolocator.city_timezone(match.group(1).strip())
                         local_timezone = timezone(parsed_timezone)
                         # set start time using the local city timezone
                         start = datetime.strptime(start_str, "%I:%M %p %d/%m/%Y")
